@@ -8,7 +8,6 @@ import (
 	"time"
 
 	"github.com/r3labs/diff/v2"
-
 	"github.com/snyk/driftctl/pkg/alerter"
 	"github.com/snyk/driftctl/pkg/resource"
 )
@@ -27,11 +26,12 @@ type Difference struct {
 }
 
 type Summary struct {
-	TotalResources int `json:"total_resources"`
-	TotalDrifted   int `json:"total_changed"`
-	TotalUnmanaged int `json:"total_unmanaged"`
-	TotalDeleted   int `json:"total_missing"`
-	TotalManaged   int `json:"total_managed"`
+	TotalResources      int  `json:"total_resources"`
+	TotalDrifted        int  `json:"total_changed"`
+	TotalUnmanaged      int  `json:"total_unmanaged"`
+	TotalDeleted        int  `json:"total_missing"`
+	TotalManaged        int  `json:"total_managed"`
+	TotalIaCSourceCount uint `json:"total_iac_source_count"`
 }
 
 type Analysis struct {
@@ -54,6 +54,7 @@ type serializableDifference struct {
 }
 
 type serializableAnalysis struct {
+	Options         AnalyzerOptions                        `json:"options"`
 	Summary         Summary                                `json:"summary"`
 	Managed         []resource.SerializableResource        `json:"managed"`
 	Unmanaged       []resource.SerializableResource        `json:"unmanaged"`
@@ -63,6 +64,7 @@ type serializableAnalysis struct {
 	Alerts          map[string][]alerter.SerializableAlert `json:"alerts"`
 	ProviderName    string                                 `json:"provider_name"`
 	ProviderVersion string                                 `json:"provider_version"`
+	ScanDuration    uint                                   `json:"scan_duration,omitempty"`
 }
 
 type GenDriftIgnoreOptions struct {
@@ -106,6 +108,8 @@ func (a Analysis) MarshalJSON() ([]byte, error) {
 	bla.Coverage = a.Coverage()
 	bla.ProviderName = a.ProviderName
 	bla.ProviderVersion = a.ProviderVersion
+	bla.ScanDuration = uint(a.Duration.Seconds())
+	bla.Options = a.Options()
 
 	return json.Marshal(bla)
 }
@@ -166,6 +170,9 @@ func (a *Analysis) UnmarshalJSON(bytes []byte) error {
 	}
 	a.ProviderName = bla.ProviderName
 	a.ProviderVersion = bla.ProviderVersion
+	a.SetIaCSourceCount(bla.Summary.TotalIaCSourceCount)
+	a.Duration = time.Duration(bla.ScanDuration) * time.Second
+	a.options = bla.Options
 	return nil
 }
 
@@ -208,6 +215,10 @@ func (a *Analysis) SetOptions(options AnalyzerOptions) {
 	a.options = options
 }
 
+func (a *Analysis) SetIaCSourceCount(i uint) {
+	a.summary.TotalIaCSourceCount = i
+}
+
 func (a *Analysis) Coverage() int {
 	if a.summary.TotalResources > 0 {
 		return int((float32(a.summary.TotalManaged) / float32(a.summary.TotalResources)) * 100.0)
