@@ -6,9 +6,9 @@ import (
 )
 
 type ProviderConfig struct {
-	Key     string
-	Version string
-	Postfix string
+	Key       string
+	Version   string
+	ConfigDir string
 }
 
 func (c *ProviderConfig) GetDownloadUrl() string {
@@ -28,8 +28,5 @@ func (c *ProviderConfig) GetDownloadUrl() string {
 }
 
 func (c *ProviderConfig) GetBinaryName() string {
-	if c.Postfix == "" {
-		return fmt.Sprintf("terraform-provider-%s_v%s", c.Key, c.Version)
-	}
-	return fmt.Sprintf("terraform-provider-%s_v%s_%s", c.Key, c.Version, c.Postfix)
+	return fmt.Sprintf("terraform-provider-%s_v%s", c.Key, c.Version)
 }
